
# Slot: is_a




URI: [linkml:class_definition_is_a](https://w3id.org/linkml/class_definition_is_a)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..1</sub> [ClassDefinition](ClassDefinition.md)

## Parents

 *  is_a: [is_a](is_a.md)

## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
